@@ -29,12 +29,11 @@ class ELISALIB_EXPORT ElisaConfigurationDialog : public QObject
                WRITE setForceUsageOfSlowFileSystemIndexing
                NOTIFY forceUsageOfSlowFileSystemIndexingChanged)
 
-Q_PROPERTY(bool showNowPlayingBackground
+    Q_PROPERTY(bool showNowPlayingBackground
                READ showNowPlayingBackground
                WRITE setShowNowPlayingBackground
                NOTIFY showNowPlayingBackgroundChanged)
 
-
     Q_PROPERTY(bool showProgressInTaskBar
                READ showProgressInTaskBar
                WRITE setShowProgressInTaskBar
@@ -64,10 +63,15 @@ Q_PROPERTY(bool showNowPlayingBackground
                WRITE setPlayAtStartup
                NOTIFY playAtStartupChanged)
 
-        Q_PROPERTY(QString colorScheme
-                   READ colorScheme
-                   WRITE setColorScheme
-                   NOTIFY colorSchemeChanged)
+    Q_PROPERTY(bool scanAtStartup
+               READ scanAtStartup
+               WRITE setScanAtStartup
+               NOTIFY scanAtStartupChanged)
+
+    Q_PROPERTY(QString colorScheme
+               READ colorScheme
+               WRITE setColorScheme
+               NOTIFY colorSchemeChanged)
 
     Q_PROPERTY(bool useFavoriteStyleRatings
                READ useFavoriteStyleRatings
@@ -123,6 +127,11 @@ public:
         return mPlayAtStartup;
     }
 
+    [[nodiscard]] bool scanAtStartup() const
+    {
+        return mScanAtStartup;
+    }
+
     [[nodiscard]] QString colorScheme() const
     {
         return mColorScheme;
@@ -156,6 +165,8 @@ Q_SIGNALS:
 
     void playAtStartupChanged();
 
+    void scanAtStartupChanged();
+
     void colorSchemeChanged();
 
     void useFavoriteStyleRatingsChanged();
@@ -182,6 +193,8 @@ public Q_SLOTS:
 
     void setPlayAtStartup(bool playAtStartup);
 
+    void setScanAtStartup(bool scanAtStartup);
+
     void setColorScheme(const QString &scheme);
 
     void setUseFavoriteStyleRatings(bool useFavoriteStyleRatings);
@@ -210,6 +223,8 @@ private:
 
     bool mPlayAtStartup = false;
 
+    bool mScanAtStartup = true;
+
     bool mUseFavoriteStyleRatings = false;
 
     QString mColorScheme;
